@@ -17,7 +17,7 @@ create_test_forecast_validation <- function(){
     type = "flu_a",
     validate_window_size = 7,
     window_size = 7,
-    smooth_data = T,
+    smooth_data = TRUE,
     smoothing_cutoff = 10
   )
 
